<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Container;

class NodeManagement extends \Google\Model
{
  /**
   * @var bool
   */
  public $autoRepair;
  /**
   * @var bool
   */
  public $autoUpgrade;
  protected $upgradeOptionsType = AutoUpgradeOptions::class;
  protected $upgradeOptionsDataType = '';

  /**
   * @param bool
   */
  public function setAutoRepair($autoRepair)
  {
    $this->autoRepair = $autoRepair;
  }
  /**
   * @return bool
   */
  public function getAutoRepair()
  {
    return $this->autoRepair;
  }
  /**
   * @param bool
   */
  public function setAutoUpgrade($autoUpgrade)
  {
    $this->autoUpgrade = $autoUpgrade;
  }
  /**
   * @return bool
   */
  public function getAutoUpgrade()
  {
    return $this->autoUpgrade;
  }
  /**
   * @param AutoUpgradeOptions
   */
  public function setUpgradeOptions(AutoUpgradeOptions $upgradeOptions)
  {
    $this->upgradeOptions = $upgradeOptions;
  }
  /**
   * @return AutoUpgradeOptions
   */
  public function getUpgradeOptions()
  {
    return $this->upgradeOptions;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(NodeManagement::class, 'Google_Service_Container_NodeManagement');
